<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Information</name>
    <message>
        <location filename="../Information.js" line="+285"/>
        <source>Information Tools</source>
        <translation>情報ツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show information tools</source>
        <translation>情報ツールを表示</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Info</source>
        <translation>&amp;I 情報</translation>
    </message>
    <message>
        <location filename="../Information.ui" line="+17"/>
        <source>Add measurement to drawing</source>
        <translation>図面に寸法を追加</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Text height:</source>
        <translation>テキストの高さ:</translation>
    </message>
    <message>
        <source>Text Height:</source>
        <translation type="vanished">テキストの高さ:</translation>
    </message>
</context>
</TS>
